function [FRE,gmRE,Jpq,INFO,PSIhat] = ...
    robfiltLPVRESYN(P,PSIICT,Mm,gm,nw,nv,ny,varargin)
%robfiltLPVRESYN re-synthesizes the filter using LPVSYN. This function is
%called after robfiltsynEngine is called.

%% Re-cast problem as nominal LPV output feedback synthesis
% Create PSIdagger
[PSIhat,Jpq,~,PSIdag] = piReconstruction(PSIICT,Mm,nw,nv);

% Extract channel sizes
[nr,nc] = size(P); % total number of I/O channels
nz = nr - nv - ny; % size of outputs to be estimated
nd = nc - nw; % size of input disturbances

% Sum block for estimation error
sumJnc = makesumJnc(nz,varargin{:});

% Create scaled plant
sf = 1/sqrt(gm); % scale factor
sfo = blkdiag(eye(nv),sf.*eye(ny),sf.*eye(nz)); % output scale factor block
sfi = blkdiag(eye(nw),sf.*eye(nd)); % input scale factor block
PSCL = sfo*P*sfi; % scaled plant
PSCL = set(PSCL,'InputGroup',P.InputGroup,'OutputGroup',P.OutputGroup,...
    'StateName',P.StateName,'InputName',P.InputName,'OutputName',P.OutputName);

% Generalized plant for LPV synthesis
Q = connect(PSCL,PSIdag,sumJnc,{'wF','d','zhat'},{'vF','e','y'});

% LPV synthesis
% NOTE: By default, the method used in lpvsyn is 'BackOff'. This is a
% two-stage synthesis, wherein the 'MinGamma' problem is first solved and
% then the 'MaxFeas' problem is solved with a default BackOffFactor of 1.2.
% However, for this lpv synthesis, the best upper bound is desired. Hence,
% the mode is set as 'MinGamma'.
opt = lpvsynOptions('Method','MinGamma');
[FRE,gmRE,INFO] = lpvsyn(Q,ny,nz,opt);

%% Input/output grouping for filter
% Filter order
n = order(FRE);

% state names of filter
FStateName = cell(1,n);
for k = 1:n
    FStateName{1,k} = ['xf(',num2str(k),')'];
end

% input (y) to filter
if length(FRE.InputName) == 1
    FInpName = 'y(1)';
else
    FInpName = 'y'; % automatic vectorization expected
end

% output (xhat) from filter
if length(FRE.OutputName) == 1
    FOutName = 'zhat(1)';
else
    FOutName = 'zhat'; % automatic vectorization expected
end

% Set properties for FRE
FRE = set(FRE,'StateName',FStateName,...
    'InputName',FInpName,'OutputName',FOutName,...
    'InputGroup',struct('Measurement',1:length(FRE.InputName)),...
    'OutputGroup',struct('OutputEstimate',1:length(FRE.OutputName)));

end
